Updated comments and help text in mesos-execute.

Review: https://reviews.apache.org/r/60417


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/abe9d1b4
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/abe9d1b4
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/abe9d1b4

Branch: refs/heads/master
Commit: abe9d1b4aca1b511ce41a2479d4a44d3d7cfe2be
Parents: 4ec8207
Author: Neil Conway <neil.con...@gmail.com>
Authored: Sat Jun 24 13:19:35 2017 -0700
Committer: Neil Conway <neil.con...@gmail.com>
Committed: Sat Jun 24 20:57:41 2017 -0700

----------------------------------------------------------------------
 src/cli/execute.cpp | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/abe9d1b4/src/cli/execute.cpp
----------------------------------------------------------------------
diff --git a/src/cli/execute.cpp b/src/cli/execute.cpp
index 58eaa47..6e15344 100644
--- a/src/cli/execute.cpp
+++ b/src/cli/execute.cpp
@@ -245,8 +245,8 @@ public:
     add(&Flags::framework_capabilities,
         "framework_capabilities",
         "Comma-separated list of optional framework capabilities to enable.\n"
-        "TASK_KILLING_STATE is always enabled. PARTITION_AWARE is enabled\n"
-        "unless --no-partition-aware is specified.");
+        "RESERVATION_REFINEMENT and TASK_KILLING_STATE are always enabled.\n"
+        "PARTITION_AWARE is enabled unless --no-partition-aware is 
specified.");
 
     add(&Flags::containerizer,
         "containerizer",
@@ -1035,7 +1035,8 @@ int main(int argc, char** argv)
     return EXIT_FAILURE;
   }
 
   // Always enable the TASK_KILLING_STATE capability.
   vector<FrameworkInfo::Capability::Type> frameworkCapabilities = {
     FrameworkInfo::Capability::RESERVATION_REFINEMENT,
     FrameworkInfo::Capability::TASK_KILLING_STATE,
@@ -1035,7 +1035,8 @@ int main(int argc, char** argv)
   }
 
-  // Always enable the TASK_KILLING_STATE capability.
+  // Always enable the RESERVATION_REFINEMENT and TASK_KILLING_STATE
+  // capabilities.
   vector<FrameworkInfo::Capability::Type> frameworkCapabilities = {
     FrameworkInfo::Capability::RESERVATION_REFINEMENT,

Reply via email to